@@ -3,31 +3,20 @@ use warnings;
 
 package Thread::IID;
 BEGIN {
-  $Thread::IID::VERSION = '0.03';
+  $Thread::IID::VERSION = '0.04';
 }
 
- use 5.008001;
+use 5.008001;
 
-require Exporter;
+our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Thread::IID ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-  interpreter_id
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = ();
-
-our $VERSION;
+BEGIN {
+    require Exporter;
+    @ISA = qw(Exporter);
+    %EXPORT_TAGS = ( 'all' => [ qw(interpreter_id) ] );
+    @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+    @EXPORT = ();
+}
 
 require XSLoader;
 XSLoader::load('Thread::IID', $VERSION);
@@ -43,7 +32,7 @@ Thread::IID - unique Interpreter IDs
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
